@@ -53,6 +53,16 @@ class TestOptions(unittest.TestCase):
         void foo() {
         #if
         #endif
+            if(bar)
+            {
+            }
+            switch(bar)
+            {
+              case 0: break;
+              case 1: break;
+              case 2: break;
+              case 3: break;
+            }
         }
         '''
         
@@ -69,28 +79,34 @@ class TestOptions(unittest.TestCase):
         
     def test_with_preprocessor_counted_in_CCN(self):
         self.runApplicationWithArgv(['lizard'])
-        self.assertEqual(2, self.fileInfos[0].function_list[0].cyclomatic_complexity)
+        self.assertEqual(7, self.fileInfos[0].function_list[0].cyclomatic_complexity)
 
     def test_not_with_preprocessor_counted_in_CCN(self):
         self.runApplicationWithArgv(['lizard', '-P'])
-        self.assertEqual(1, self.fileInfos[0].function_list[0].cyclomatic_complexity)
+        self.assertEqual(6, self.fileInfos[0].function_list[0].cyclomatic_complexity)
         
     def test_using_the_WordCount_plugin(self):
         self.runApplicationWithArgv(['lizard', '-EWordCount'])
         self.assertEqual(1, self.fileInfos[0].wordCount["foo"])
 
+    def test_using_modified_ccn(self):
+        self.runApplicationWithArgv(['lizard', '--modified'])
+        self.assertEqual(4, self.fileInfos[0].function_list[0].cyclomatic_complexity)
 
-from lizard import get_whitelist
+
+from lizard import parse_args
 class TestOptionParsing(unittest.TestCase):
 
     @patch('lizard.open', create=True)
     def test_load_whitelist_from_file(self, mock_open):
         mock_open.return_value.__enter__.return_value.read.return_value = "foo"
-        self.assertEqual("foo", get_whitelist())
+        _, options = parse_args(['lizard'])
+        self.assertEqual("foo", options.whitelist)
         mock_open.assert_called_with('whitelizard.txt', mode='r')
 
     @patch('lizard.open', create=True)
     def test_should_be_empty_if_whitelist_file_doesnot_exist(self, mock_open):
         mock_open.side_effect = IOError
-        self.assertEqual("", get_whitelist())
+        _, options = parse_args(['lizard'])
+        self.assertEqual("", options.whitelist)
 
